﻿using System;
using System.Collections.Generic;
using TUIO;

namespace TouchTokens
{
	/*
	 *   Authors: Caroline Appert (caroline.appert@lri.fr)
	 *   Copyright (c) Univ. Paris-Sud XI, 2015. All Rights Reserved
	 *   Licensed under the GNU LGPL. For full terms see the file COPYING.
	*/

	public class TokenTemplate : MultiTouchInput
	{

		protected internal string tokenID;
		protected internal double distance;

		protected internal int[] rgba = new int[4];
		protected internal string shape;
		protected internal double ray;
		protected internal double inner;

		public TokenTemplate(List<TouchPoint> points, string tokenID) : base(points)
		{
			this.points = points;
			this.tokenID = tokenID;
			this.rgba[0] = this.rgba[1] = this.rgba[2] = this.rgba[3] = -1;
			shape = "";
			// could be overwritten by the tempalte file
			TouchPoint c = TouchTokenRecognizer.centroid(points);
			ray = 0;
			foreach(TouchPoint p in points){
				double dist= Math.Pow((p.X - c.X) * (p.X - c.X) + (p.Y - c.Y) * (p.Y - c.Y), 0.5);
				if (dist > ray) ray = dist;
			}
			inner = ray;
		}

		public override string ToString()
		{
			string points = "";
			foreach (TouchPoint pt in this.points)
			{
				points += "(" + pt.X + "," + pt.Y + ")";
			}
			points += "";
			string c = "" + rgba[0] + " " + rgba[1] + " " + rgba[2] + " " + rgba[3] + "";
			return tokenID + "points: [" + points + "] " + "rgba: [" +c + "] shape: "+ shape + " ray: " + ray + " inner: " + inner;
		}

		public virtual int[] RGBA {
			get
			{
				return rgba;
			}
			set
			{
				this.rgba = value;
			}
		}
		public virtual string Shape {
			get
			{
				return shape;
			}
			set
			{
				this.shape = value;
			}
		}
		public virtual double Ray {
			get
			{
				return ray;
			}
			set
			{
				this.ray = value;
			}
		}
		public virtual double Inner {
			get
			{
				return inner;
			}
			set
			{
				this.inner = value;
			}
		}

		public override List<TouchPoint> Points
		{
			get
			{
				return points;
			}
			set
			{
				this.points = value;
			}
		}


		public virtual string TokenID
		{
			get
			{
				return tokenID;
			}
			set
			{
				this.tokenID = value;
			}
		}


		public virtual double Distance
		{
			get
			{
				return distance;
			}
			set
			{
				this.distance = value;
			}
		}
	}

}